@@ -1,5 +1,4 @@
-import type { Node } from "domhandler";
-import { hasChildren } from "./tagtypes";
+import { hasChildren, Node } from "domhandler";
 
 /**
  * Given an array of nodes, remove any member that is contained by another.
@@ -126,7 +125,7 @@ export function compareDocumentPosition(nodeA: Node, nodeB: Node): number {
  * @param nodes Array of DOM nodes.
  * @returns Collection of unique nodes, sorted in document order.
  */
-export function uniqueSort(nodes: Node[]): Node[] {
+export function uniqueSort<T extends Node>(nodes: T[]): T[] {
     nodes = nodes.filter((node, i, arr) => !arr.includes(node, i + 1));
 
     nodes.sort((a, b) => {
